@@ -1,9 +1,10 @@
 use std::{
-    collections::HashMap,
     env,
     path::{Path, PathBuf},
 };
 
+use garde::Validate;
+use rustc_hash::FxHashMap;
 use serde::Deserialize;
 use smart_default::SmartDefault;
 use umbra::optional;
@@ -11,7 +12,7 @@ use umbra::optional;
 use crate::{
     color::{ColorTheme, OptionalColorTheme},
     keybind::KeyBind,
-    CommitOrderType, GraphWidthType, ImageProtocolType, InitialSelection, Result,
+    CommitOrderType, GraphStyle, GraphWidthType, ImageProtocolType, InitialSelection, Result,
 };
 
 const XDG_CONFIG_HOME_ENV_NAME: &str = "XDG_CONFIG_HOME";
@@ -50,6 +51,9 @@ pub fn load() -> Result<(
             }
         }
     }?;
+
+    config.validate()?;
+
     Ok((
         config.core,
         config.ui,
@@ -78,29 +82,38 @@ fn read_config_from_path(path: &Path) -> Result<Config> {
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Default, Clone, PartialEq, Eq)]
+#[derive(Debug, Default, Clone, PartialEq, Eq, Validate)]
 struct Config {
+    #[garde(dive)]
     #[nested]
     core: CoreConfig,
+    #[garde(dive)]
     #[nested]
     ui: UiConfig,
+    #[garde(dive)]
     #[nested]
     graph: GraphConfig,
+    #[garde(skip)]
     #[nested]
     color: ColorTheme,
     // The user customed keybinds, please ref `assets/default-keybind.toml`
+    #[garde(skip)]
     keybind: Option<KeyBind>,
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Default, Clone, PartialEq, Eq)]
+#[derive(Debug, Default, Clone, PartialEq, Eq, Validate)]
 pub struct CoreConfig {
+    #[garde(skip)]
     #[nested]
     pub option: CoreOptionConfig,
+    #[garde(skip)]
     #[nested]
     pub search: CoreSearchConfig,
+    #[garde(dive)]
     #[nested]
     pub user_command: CoreUserCommandConfig,
+    #[garde(dive)]
     #[nested]
     pub external: CoreExternalConfig,
 }
@@ -111,6 +124,7 @@ pub struct CoreOptionConfig {
     pub protocol: Option<ImageProtocolType>,
     pub order: Option<CommitOrderType>,
     pub graph_width: Option<GraphWidthType>,
+    pub graph_style: Option<GraphStyle>,
     pub initial_selection: Option<InitialSelection>,
 }
 
@@ -124,9 +138,10 @@ pub struct CoreSearchConfig {
 }
 
 #[optional]
-#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault, Validate)]
 pub struct CoreUserCommandConfig {
-    #[default(HashMap::from([("1".into(), UserCommand {
+    #[garde(dive)]
+    #[default(FxHashMap::from_iter([("1".into(), UserCommand {
         name: "git diff".into(),
         commands: vec![
             "git".into(),
@@ -137,7 +152,8 @@ pub struct CoreUserCommandConfig {
             "{{target_hash}}".into(),
         ],
     })]))]
-    pub commands: HashMap<String, UserCommand>,
+    pub commands: FxHashMap<String, UserCommand>,
+    #[garde(range(min = 0))]
     #[default = 4]
     pub tab_width: u16,
 }
@@ -163,7 +179,7 @@ impl<'de> Deserialize<'de> for OptionalCoreUserCommandConfig {
             where
                 V: MapAccess<'de>,
             {
-                let mut commands = HashMap::new();
+                let mut commands = FxHashMap::default();
                 let mut tab_width = None;
 
                 while let Some(key) = map.next_key::<String>()? {
@@ -204,23 +220,30 @@ impl<'de> Deserialize<'de> for OptionalCoreUserCommandConfig {
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Deserialize, Validate)]
 pub struct UserCommand {
+    #[garde(length(min = 1))]
     pub name: String,
+    #[garde(length(min = 1), inner(length(min = 1)))]
     pub commands: Vec<String>,
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Default, Clone, PartialEq, Eq)]
+#[derive(Debug, Default, Clone, PartialEq, Eq, Validate)]
 pub struct UiConfig {
+    #[garde(skip)]
     #[nested]
     pub common: UiCommonConfig,
+    #[garde(dive)]
     #[nested]
     pub list: UiListConfig,
+    #[garde(dive)]
     #[nested]
     pub detail: UiDetailConfig,
+    #[garde(dive)]
     #[nested]
     pub user_command: UiUserCommandConfig,
+    #[garde(dive)]
     #[nested]
     pub refs: UiRefsConfig,
 }
@@ -238,72 +261,86 @@ pub enum CursorType {
     Virtual(String),
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Deserialize, Default)]
+#[derive(Debug, Clone, PartialEq, Eq, Deserialize, Default, Validate)]
 pub enum ClipboardConfig {
     #[default]
     Auto,
     Custom {
+        #[garde(length(min = 1), inner(length(min = 1)))]
         commands: Vec<String>,
     },
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault, Validate)]
 pub struct CoreExternalConfig {
+    #[garde(dive)]
     #[default(ClipboardConfig::Auto)]
     pub clipboard: ClipboardConfig,
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault, Validate)]
 pub struct UiListConfig {
+    #[garde(range(min = 1))]
     #[default = 20]
     pub subject_min_width: u16,
+    #[garde(length(min = 1))]
     #[default = "%Y-%m-%d"]
     pub date_format: String,
+    #[garde(range(min = 0))]
     #[default = 10]
     pub date_width: u16,
+    #[garde(skip)]
     #[default = true]
     pub date_local: bool,
+    #[garde(range(min = 0))]
     #[default = 20]
     pub name_width: u16,
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault, Validate)]
 pub struct UiDetailConfig {
+    #[garde(range(min = 1))]
     #[default = 20]
     pub height: u16,
+    #[garde(length(min = 1))]
     #[default = "%Y-%m-%d %H:%M:%S %z"]
     pub date_format: String,
+    #[garde(skip)]
     #[default = true]
     pub date_local: bool,
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault, Validate)]
 pub struct UiUserCommandConfig {
+    #[garde(range(min = 1))]
     #[default = 20]
     pub height: u16,
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault, Validate)]
 pub struct UiRefsConfig {
+    #[garde(range(min = 1))]
     #[default = 26]
     pub width: u16,
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Default, Clone, PartialEq, Eq)]
+#[derive(Debug, Default, Clone, PartialEq, Eq, Validate)]
 pub struct GraphConfig {
+    #[garde(dive)]
     #[nested]
     pub color: GraphColorConfig,
 }
 
 #[optional(derives = [Deserialize])]
-#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault, Validate)]
 pub struct GraphColorConfig {
+    #[garde(length(min = 1), inner(pattern(r"^#([0-9a-fA-F]{6}|[0-9a-fA-F]{8})$")))]
     #[default(vec![
         "#E06C76".into(),
         "#98C379".into(),
@@ -313,8 +350,10 @@ pub struct GraphColorConfig {
         "#56B6C2".into(),
     ])]
     pub branches: Vec<String>,
+    #[garde(pattern(r"^#([0-9a-fA-F]{6}|[0-9a-fA-F]{8})$"))]
     #[default = "#00000000"]
     pub edge: String,
+    #[garde(pattern(r"^#([0-9a-fA-F]{6}|[0-9a-fA-F]{8})$"))]
     #[default = "#00000000"]
     pub background: String,
 }
@@ -332,6 +371,7 @@ mod tests {
                     protocol: None,
                     order: None,
                     graph_width: None,
+                    graph_style: None,
                     initial_selection: None,
                 },
                 search: CoreSearchConfig {
@@ -339,7 +379,7 @@ mod tests {
                     fuzzy: false,
                 },
                 user_command: CoreUserCommandConfig {
-                    commands: HashMap::from([(
+                    commands: FxHashMap::from_iter([(
                         "1".into(),
                         UserCommand {
                             name: "git diff".into(),
@@ -405,6 +445,7 @@ mod tests {
             protocol = "kitty"
             order = "topo"
             graph_width = "single"
+            graph_style = "angular"
             initial_selection = "head"
             [core.search]
             ignore_case = true
@@ -442,6 +483,7 @@ mod tests {
                     protocol: Some(ImageProtocolType::Kitty),
                     order: Some(CommitOrderType::Topo),
                     graph_width: Some(GraphWidthType::Single),
+                    graph_style: Some(GraphStyle::Angular),
                     initial_selection: Some(InitialSelection::Head),
                 },
                 search: CoreSearchConfig {
@@ -449,7 +491,7 @@ mod tests {
                     fuzzy: true,
                 },
                 user_command: CoreUserCommandConfig {
-                    commands: HashMap::from([
+                    commands: FxHashMap::from_iter([
                         (
                             "1".into(),
                             UserCommand {
@@ -528,6 +570,7 @@ mod tests {
                     protocol: None,
                     order: None,
                     graph_width: None,
+                    graph_style: None,
                     initial_selection: None,
                 },
                 search: CoreSearchConfig {
@@ -535,7 +578,7 @@ mod tests {
                     fuzzy: false,
                 },
                 user_command: CoreUserCommandConfig {
-                    commands: HashMap::from([(
+                    commands: FxHashMap::from_iter([(
                         "1".into(),
                         UserCommand {
                             name: "git diff".into(),
