@@ -23,6 +23,10 @@ use serde::Deserialize;
 #[derive(Parser)]
 #[command(version)]
 struct Args {
+    /// Maximum number of commits to render
+    #[arg(short = 'n', long, value_name = "NUMBER")]
+    max_count: Option<usize>,
+
     /// Image protocol to render graph [default: auto]
     #[arg(short, long, value_name = "TYPE")]
     protocol: Option<ImageProtocolType>,
@@ -35,6 +39,10 @@ struct Args {
     #[arg(short, long, value_name = "TYPE")]
     graph_width: Option<GraphWidthType>,
 
+    /// Commit graph image edge style [default: rounded]
+    #[arg(short = 's', long, value_name = "TYPE")]
+    graph_style: Option<GraphStyle>,
+
     /// Initial selection of commit [default: latest]
     #[arg(short, long, value_name = "TYPE")]
     initial_selection: Option<InitialSelection>,
@@ -88,6 +96,23 @@ pub enum GraphWidthType {
     Single,
 }
 
+#[derive(Debug, Clone, Copy, PartialEq, Eq, ValueEnum, Deserialize)]
+#[serde(rename_all = "lowercase")]
+pub enum GraphStyle {
+    Rounded,
+    Angular,
+}
+
+impl From<Option<GraphStyle>> for graph::GraphStyle {
+    fn from(style: Option<GraphStyle>) -> Self {
+        match style {
+            Some(GraphStyle::Rounded) => graph::GraphStyle::Rounded,
+            Some(GraphStyle::Angular) => graph::GraphStyle::Angular,
+            None => graph::GraphStyle::Rounded,
+        }
+    }
+}
+
 #[derive(Debug, Clone, Copy, PartialEq, Eq, ValueEnum, Deserialize)]
 #[serde(rename_all = "lowercase")]
 pub enum InitialSelection {
@@ -112,9 +137,11 @@ pub fn run() -> Result<()> {
     let (core_config, ui_config, graph_config, color_theme, key_bind_patch) = config::load()?;
     let key_bind = keybind::KeyBind::new(key_bind_patch);
 
+    let max_count = args.max_count;
     let image_protocol = args.protocol.or(core_config.option.protocol).into();
     let order = args.order.or(core_config.option.order).into();
     let graph_width = args.graph_width.or(core_config.option.graph_width);
+    let graph_style = args.graph_style.or(core_config.option.graph_style).into();
     let initial_selection = args
         .initial_selection
         .or(core_config.option.initial_selection)
@@ -122,7 +149,7 @@ pub fn run() -> Result<()> {
 
     let graph_color_set = color::GraphColorSet::new(&graph_config.color);
 
-    let repository = git::Repository::load(Path::new("."), order)?;
+    let repository = git::Repository::load(Path::new("."), order, max_count)?;
 
     let graph = graph::calc_graph(&repository);
 
@@ -132,6 +159,7 @@ pub fn run() -> Result<()> {
         &graph,
         &graph_color_set,
         cell_width_type,
+        graph_style,
         image_protocol,
         args.preload,
     );
