@@ -63,12 +63,12 @@ impl<'a> ListView<'a> {
                 UserEvent::Quit => {
                     self.tx.send(AppEvent::Quit);
                 }
-                UserEvent::NavigateDown => {
+                UserEvent::NavigateDown | UserEvent::SelectDown => {
                     for _ in 0..count {
                         self.as_mut_list_state().select_next();
                     }
                 }
-                UserEvent::NavigateUp => {
+                UserEvent::NavigateUp | UserEvent::SelectUp => {
                     for _ in 0..count {
                         self.as_mut_list_state().select_prev();
                     }
