@@ -1,5 +1,3 @@
-use std::collections::HashMap;
-
 use fuzzy_matcher::{skim::SkimMatcherV2, FuzzyMatcher};
 use laurier::highlight::highlight_matched_text;
 use once_cell::sync::Lazy;
@@ -11,6 +9,7 @@ use ratatui::{
     text::{Line, Span},
     widgets::{List, ListItem, StatefulWidget, Widget},
 };
+use rustc_hash::{FxHashMap, FxHashSet};
 use tui_input::{backend::crossterm::EventHandler, Input};
 
 use crate::{
@@ -78,7 +77,7 @@ pub enum TransientMessage {
 
 #[derive(Debug, Default, Clone)]
 struct SearchMatch {
-    refs: HashMap<String, SearchMatchPosition>,
+    refs: FxHashMap<String, SearchMatchPosition>,
     subject: Option<SearchMatchPosition>,
     author_name: Option<SearchMatchPosition>,
     commit_hash: Option<SearchMatchPosition>,
@@ -181,11 +180,12 @@ impl SearchMatcher {
 #[derive(Debug)]
 pub struct CommitListState<'a> {
     commits: Vec<CommitInfo<'a>>,
+    commit_hash_set: FxHashSet<&'a CommitHash>,
     graph_image_manager: GraphImageManager<'a>,
     graph_cell_width: u16,
     head: &'a Head,
 
-    ref_name_to_commit_index_map: HashMap<&'a str, usize>,
+    ref_name_to_commit_index_map: FxHashMap<&'a str, usize>,
 
     search_state: SearchState,
     search_input: Input,
@@ -206,13 +206,15 @@ impl<'a> CommitListState<'a> {
         graph_image_manager: GraphImageManager<'a>,
         graph_cell_width: u16,
         head: &'a Head,
-        ref_name_to_commit_index_map: HashMap<&'a str, usize>,
+        ref_name_to_commit_index_map: FxHashMap<&'a str, usize>,
         default_ignore_case: bool,
         default_fuzzy: bool,
     ) -> CommitListState<'a> {
         let total = commits.len();
+        let commit_hash_set = commits.iter().map(|c| &c.commit.commit_hash).collect();
         CommitListState {
             commits,
+            commit_hash_set,
             graph_image_manager,
             graph_cell_width,
             head,
@@ -243,8 +245,10 @@ impl<'a> CommitListState<'a> {
 
     pub fn select_parent(&mut self) {
         if let Some(target_commit) = self.selected_commit_parent_hash().cloned() {
-            while target_commit.as_str() != self.selected_commit_hash().as_str() {
-                self.select_next();
+            if self.commit_hash_set.contains(&target_commit) {
+                while target_commit.as_str() != self.selected_commit_hash().as_str() {
+                    self.select_next();
+                }
             }
         }
     }
@@ -961,7 +965,7 @@ impl CommitList<'_> {
 fn refs_spans<'a>(
     commit_info: &'a CommitInfo,
     head: &'a Head,
-    refs_matches: &'a HashMap<String, SearchMatchPosition>,
+    refs_matches: &'a FxHashMap<String, SearchMatchPosition>,
     color_theme: &'a ColorTheme,
 ) -> Vec<Span<'a>> {
     let refs = &commit_info.refs;
